@@ -1,13 +1,13 @@
 DrawVectors <-
-function(measured_data_,real_data_){ #PODER CAMBIAR TAMAO DE LAS FLECHAS
+function(final_data_,initial_data_){ #PODER CAMBIAR TAMAO DE LAS FLECHAS
 	
 	plot.new();
 	par(fg="white");
 	
-	length_x_max=max(c(real_data_[,1],measured_data_[,1]));
-	length_y_max=max(c(real_data_[,2],measured_data_[,2]));
-    length_x_min=min(c(real_data_[,1],measured_data_[,1]));
-    length_y_min=min(c(real_data_[,2],measured_data_[,2]));
+	length_x_max=max(c(initial_data_[,1],final_data_[,1]));
+	length_y_max=max(c(initial_data_[,2],final_data_[,2]));
+    length_x_min=min(c(initial_data_[,1],final_data_[,1]));
+    length_y_min=min(c(initial_data_[,2],final_data_[,2]));
 	center_x=0;
 	center_y=0;
 	
@@ -22,13 +22,13 @@ function(measured_data_,real_data_){ #PODER CAMBIAR TAMAO DE LAS FLECHAS
 	axis(side=2,pos=0,col="black",at=round(seq(0,length_y_max, len=5),2),las=1,cex.axis=0.7,font.axis=3);
 	axis(side=2,pos=0,col="black",at=round(seq(length_y_min, 0, len=5),2),las=1,cex.axis=0.7,font.axis=3);
 	
-    number_elements=length(real_data_)/2;
+    number_elements=length(initial_data_)/2;
 	for(i in 1:number_elements){                                     #si aado un paremetro ms da error en el number_elements
-		x=measured_data_[i,1]-real_data_[i,1];
-		y=measured_data_[i,2]-real_data_[i,2];
+		x=final_data_[i,1]-initial_data_[i,1];
+		y=final_data_[i,2]-initial_data_[i,2];
 
 		if((x!=0)&&(y!=0)){
-			arrows(measured_data_[i,1], measured_data_[i,2],real_data_[i,1],real_data_[i,2], length = 0,07, code = 2, col="blue");
+			arrows(final_data_[i,1], final_data_[i,2],initial_data_[i,1],initial_data_[i,2], length = 0,07, code = 2, col="blue");
 		}
 	}
 }
